@@ -1,4 +1,5 @@
 import copy
+import inspect
 from itertools import (
     chain,
 )
@@ -24,7 +25,6 @@ from django.db.models import (
 )
 from django.db.models.base import (
     ModelBase,
-    _has_contribute_to_class,
     subclass_exception,
 )
 from django.db.models.deletion import (
@@ -62,6 +62,13 @@ from m3_db_utils.strings import (
 )
 
 
+# TODO Функция перенесена из Django 2.2 в угоду совместимости с Django 1.11 используемой на текущий момент в ОБР. Стоит
+#  выпилить после повышения версии Django в ОБР
+def _has_contribute_to_class(value):
+    # Only call contribute_to_class() if it's bound.
+    return not inspect.isclass(value) and hasattr(value, 'contribute_to_class')
+
+
 class ModelEnumValue:
     """
     Значение модели-перечисления
